@@ -3,7 +3,7 @@
 ##
 
 
-newton <- function(fun, x0, dfun = NULL, ...,
+newtonRaphson <- function(fun, x0, dfun = NULL, ...,
 	               maxiter = 100, tol = .Machine$double.eps^0.5) {
 	# Newton method for finding function zeros
 	if  (is.null(dfun)) {
@@ -27,7 +27,37 @@ newton <- function(fun, x0, dfun = NULL, ...,
 	if (niter > maxiter) {
 		warning("Maximum number of iterations 'maxiter' was reached.")
 	}
-	return(list(zero=x, fzero=fx, niter=niter, estim.prec=diff))
+	return(list(root=x, f.root=fx, niter=niter, estim.prec=diff))
+}
+
+
+newtonHorner <- function(p, x0, 
+                         maxiter = 50, tol = .Machine$double.eps^0.5) {
+    n <- length(p) - 1
+    niter <- 0
+    x <- x0
+    diff <- 1 + tol
+
+    while (niter <= maxiter && diff >= tol) {
+        H <- horner(p, x)
+        if (abs(H$dy) <= tol) {
+            warning("Newton's method encountered a slope almost zero.")
+            return(list(root = NULL, f.root = NULL, deflate = NULL,
+                        iters = niter, estim.prec = Inf))
+        }
+        xnew <- x - H$y / H$dy
+        diff <- abs(x - xnew)
+        niter <- niter + 1
+        x <- xnew
+    }
+
+    if (niter > maxiter) {
+        warning("Maximum number of iterations exceeded.")
+    }
+    defl <- hornerdefl(p, x)
+
+    return(list(root = x, f.root = defl$y, deflate = defl$q,
+                iters = niter, estim.prec = diff))
 }
 
 
