@@ -18,5 +18,5 @@ assign("elapsedTime", 0, envir = .pracmaEnv)
 
     environment(.pracmaEnv) <- asNamespace("pracma")
 
-    # packageStartupMessage("Package 'pracma 1.0.5' loaded.")
+    packageStartupMessage("PRACMA 1.1.6:\nRenamed some functions to avoid shadowing R base functions.")
 }
\ No newline at end of file
